@@ -37,5 +37,7 @@ function(DS.GF.obj, y.0, e.0){
 		out$study <- y.0
 	}
 	class(out) <- "DS_GF_micro"
+	names(out$post.vec) <- c("PEB_MN", "DS_MN", "PEB_MD", "DS_MD")
+	names(out$PEB.mean) <- NULL; names(out$PEB.mode) <- NULL; names(out$DS.mean) <- NULL; names(out$DS.mode) <- NULL
 	return(out)
 }
\ No newline at end of file
